@@ -44,6 +44,10 @@ def push_schema(project, container):
     with open(os.path.join(data_dir, 'schema.json')) as fp:
         wrapper_data = json.load(fp)  # json.loads(self.docker.logs(c))
 
+    if not wrapper_data:
+        print 'No wrappers registered (empty __init__.py?). Exiting.'
+        exit(1)
+
     push_data = {'message': container.message or 'NO COMMIT MESSAGE',
                  'image_data': {'id': project.docker_registry_name + '/' + container.user + '/' + project.name,
                                 'tag': container.tag},
