@@ -19,10 +19,19 @@ def upload(project, file):
     if not executable or not server:
         print 'Uploader location or file server URL missing.'
         sys.exit(1)
+    if not os.path.isfile(file):
+        print '%s is not a file.' % file
+        sys.exit(1)
+    file = os.path.abspath(file)
     usr, sid = login(project)
     user_home = '/home/%s' % usr
     dest = os.path.join(user_home, os.path.basename(file))
+    cwd = os.path.abspath('.')
     args = [executable, '-o', 'u', '-sessionId', '-s', server, '-ssl', '-lf', file, '-rf', dest]
     logging.debug('Running cmd: %s', args)
-    p = Popen(args, stdin=PIPE)
-    p.communicate('%s\n' % sid)
\ No newline at end of file
+    os.chdir('/tmp')
+    try:
+        p = Popen(args, stdin=PIPE)
+        p.communicate('%s\n' % sid)
+    finally:
+        os.chdir(cwd)
\ No newline at end of file
