@@ -15,7 +15,7 @@ def main(argv=None, context=None):
     context = context or {}
     parser = argparse.ArgumentParser(description="Seven Bridges Wrapper SDK Tool",
                                      epilog="Try 'sbdk [COMMAND] -h' for command specific options",
-                                     prog="sbdk",
+                                     prog="sbg",
                                      version=VERSION)
     parser.add_argument('--project-dir', default='',
                         help='Use this dir instead of project dir.')
